@@ -1,9 +1,9 @@
 package SQL::Translator::Parser::Access;
 
 # -------------------------------------------------------------------
-# $Id: Access.pm,v 1.3 2005-06-28 16:39:41 mwz444 Exp $
+# $Id: Access.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # -------------------------------------------------------------------
-# Copyright (C) 2002-4 SQLFairy Authors
+# Copyright (C) 2002-2009 SQLFairy Authors
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -40,8 +40,7 @@ something similar to the output of mdbtools (http://mdbtools.sourceforge.net/).
 =cut
 
 use strict;
-use vars qw[ $DEBUG $VERSION $GRAMMAR @EXPORT_OK ];
-$VERSION = sprintf "%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/;
+use vars qw[ $DEBUG $GRAMMAR @EXPORT_OK ];
 $DEBUG   = 0 unless defined $DEBUG;
 
 use Data::Dumper;
