@@ -1,9 +1,9 @@
 package SQL::Translator::Producer::YAML;
 
 # -------------------------------------------------------------------
-# $Id: YAML.pm,v 1.8 2004/02/09 23:02:17 kycl4rk Exp $
+# $Id: YAML.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # -------------------------------------------------------------------
-# Copyright (C) 2002-4 SQLFairy Authors
+# Copyright (C) 2002-2009 SQLFairy Authors
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -40,15 +40,13 @@ takes a long time.
 =cut
 
 use strict;
-use vars qw($VERSION);
-$VERSION = sprintf "%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/;
 
 use YAML qw(Dump);
 
 # -------------------------------------------------------------------
 sub produce {
-    my $translator  = shift;
-    my $schema      = $translator->schema;
+    my $translator = shift;
+    my $schema     = $translator->schema;
 
     return Dump({
         schema => {
@@ -68,6 +66,18 @@ sub produce {
                 map { ($_->name => view_procedure($_)) } 
                     $schema->get_procedures,
             },
+        },
+        translator => {
+            add_drop_table => $translator->add_drop_table,
+            filename       => $translator->filename,
+            no_comments    => $translator->no_comments,
+            parser_args    => $translator->parser_args,
+            producer_args  => $translator->producer_args,
+            parser_type    => $translator->parser_type,
+            producer_type  => $translator->producer_type,
+            show_warnings  => $translator->show_warnings,
+            trace          => $translator->trace,
+            version        => $translator->version,
         }
     });
 }
@@ -80,7 +90,7 @@ sub view_table {
         'name'        => $table->name,
         'order'       => $table->order,
         'options'     => $table->options  || [],
-        'comments'    => $table->comments || '',
+        $table->comments ? ('comments'    => $table->comments ) : (),
         'constraints' => [
             map { view_constraint($_) } $table->get_constraints
         ],
@@ -101,7 +111,7 @@ sub view_constraint {
     return {
         'deferrable'       => scalar $constraint->deferrable,
         'expression'       => scalar $constraint->expression,
-        'fields'           => scalar $constraint->fields,
+        'fields'           => [ map { ref $_ ? $_->name : $_ } $constraint->field_names ],
         'match_type'       => scalar $constraint->match_type,
         'name'             => scalar $constraint->name,
         'options'          => scalar $constraint->options,
@@ -118,15 +128,17 @@ sub view_field {
     my $field = shift;
 
     return {
-        'order'          => scalar $field->order,
-        'name'           => scalar $field->name,
-        'data_type'      => scalar $field->data_type,
-        'size'           => [ $field->size ],
-        'default_value'  => scalar $field->default_value,
-        'is_nullable'    => scalar $field->is_nullable,
-        'is_primary_key' => scalar $field->is_primary_key,
-        'is_unique'      => scalar $field->is_unique,
-        'extra'          => { $field->extra },
+        'order'             => scalar $field->order,
+        'name'              => scalar $field->name,
+        'data_type'         => scalar $field->data_type,
+        'size'              => [ $field->size ],
+        'default_value'     => scalar $field->default_value,
+        'is_nullable'       => scalar $field->is_nullable,
+        'is_primary_key'    => scalar $field->is_primary_key,
+        'is_unique'         => scalar $field->is_unique,
+        $field->is_auto_increment ? ('is_auto_increment' => 1) : (),
+        $field->comments ? ('comments' => $field->comments) : (),
+        'extra'             => { $field->extra },
     };
 }
 
