@@ -1,11 +1,9 @@
 package SQL::Translator::Schema;
 
-# vim: sw=4: ts=4:
-
 # ----------------------------------------------------------------------
-# $Id: Schema.pm,v 1.27 2007-10-24 10:58:35 schiffbruechige Exp $
+# $Id: Schema.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # ----------------------------------------------------------------------
-# Copyright (C) 2002-4 SQLFairy Authors
+# Copyright (C) 2002-2009 SQLFairy Authors
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -58,9 +56,7 @@ use SQL::Translator::Schema::View;
 use SQL::Translator::Utils 'parse_list_arg';
 
 use base 'SQL::Translator::Schema::Object';
-use vars qw[ $VERSION $TABLE_ORDER $VIEW_ORDER $TRIGGER_ORDER $PROC_ORDER ];
-
-$VERSION = sprintf "%d.%02d", q$Revision: 1.27 $ =~ /(\d+)\.(\d+)/;
+use vars qw[ $TABLE_ORDER $VIEW_ORDER $TRIGGER_ORDER $PROC_ORDER ];
 
 __PACKAGE__->_attributes(qw/name database translator/);
 
