@@ -1,9 +1,9 @@
 package SQL::Translator::Schema::Index;
 
 # ----------------------------------------------------------------------
-# $Id: Index.pm,v 1.18 2007-10-24 10:55:44 schiffbruechige Exp $
+# $Id: Index.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # ----------------------------------------------------------------------
-# Copyright (C) 2002-4 SQLFairy Authors
+# Copyright (C) 2002-2009 SQLFairy Authors
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -51,15 +51,13 @@ use SQL::Translator::Utils 'parse_list_arg';
 
 use base 'SQL::Translator::Schema::Object';
 
-use vars qw($VERSION $TABLE_COUNT $VIEW_COUNT);
-
-$VERSION = sprintf "%d.%02d", q$Revision: 1.18 $ =~ /(\d+)\.(\d+)/;
+use vars qw($TABLE_COUNT $VIEW_COUNT);
 
 my %VALID_INDEX_TYPE = (
-    UNIQUE,    1,
-    NORMAL,    1,
-    FULL_TEXT, 1, # MySQL only (?)
-    SPATIAL,   1, # MySQL only (?)
+  UNIQUE         => 1,
+  NORMAL         => 1,
+  FULL_TEXT      => 1, # MySQL only (?)
+  SPATIAL        => 1, # MySQL only (?)
 );
 
 # ----------------------------------------------------------------------
@@ -221,17 +219,24 @@ Get or set the index's type.
 
   my $type = $index->type('unique');
 
+Get or set the index's options (e.g., "using" or "where" for PG).  Returns
+
+Currently there are only four acceptable types: UNIQUE, NORMAL, FULL_TEXT,
+and SPATIAL. The latter two might be MySQL-specific. While both lowercase
+and uppercase types are acceptable input, this method returns the type in
+uppercase.
+
 =cut
 
     my $self = shift;
 
-    if ( my $type = shift ) {
+    if ( my $type = uc shift ) {
         return $self->error("Invalid index type: $type") 
             unless $VALID_INDEX_TYPE{ $type };
         $self->{'type'} = $type;
     }
 
-    return $self->{'type'} || NORMAL;
+    return $self->{'type'} || 'NORMAL';
 }
 
 # ----------------------------------------------------------------------
