@@ -1,9 +1,9 @@
 package SQL::Translator::Schema::Trigger;
 
 # ----------------------------------------------------------------------
-# $Id: Trigger.pm,v 1.9 2006-06-07 16:37:33 schiffbruechige Exp $
+# $Id: Trigger.pm 1444 2009-02-07 15:53:56Z ashberlin $
 # ----------------------------------------------------------------------
-# Copyright (C) 2002-4 SQLFairy Authors
+# Copyright (C) 2002-2009 SQLFairy Authors
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -32,7 +32,8 @@ SQL::Translator::Schema::Trigger - SQL::Translator trigger object
   my $trigger = SQL::Translator::Schema::Trigger->new(
       name                => 'foo',
       perform_action_when => 'before', # or after
-      database_event      => 'insert', # or update, update_on, delete
+      database_event      => 'insert', # Obsolete please use database_events!
+	  database_events     => [qw/update instert/], # or update, update_on, delete
       fields              => [],       # fields if event is "update"
       on_table            => 'foo',    # table name
       action              => '...',    # text of trigger
@@ -52,14 +53,14 @@ use SQL::Translator::Utils 'parse_list_arg';
 
 use base 'SQL::Translator::Schema::Object';
 
-use vars qw($VERSION $TABLE_COUNT $VIEW_COUNT);
+use Carp;
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/;
+use vars qw($TABLE_COUNT $VIEW_COUNT);
 
 # ----------------------------------------------------------------------
 
 __PACKAGE__->_attributes( qw/
-    name schema perform_action_when database_event fields table on_table action
+    name schema perform_action_when database_event database_events fields table on_table action
     order
 /);
 
@@ -111,27 +112,54 @@ sub database_event {
 
 =head2 database_event
 
-Gets or sets the event that triggers the trigger.
+Obosolete please use database_events!
 
-  my $ok = $trigger->database_event('insert');
+=cut
+    
+	my $self = shift;
+	
+	
+	if ( my $arg = shift ) {
+		$self->database_events( [$arg] );
+	}
+
+	return $self->error("Please use database_events the trigger has more then one events!") 
+    if (scalar @{$self->{'database_events'}} > 1);
+
+  carp 'database_event is obsolete please use database_events';
+	return (@{ $self->{'database_events'} })[0];
+}
+# ----------------------------------------------------------------------
+sub database_events {
+
+=pod
+
+=head2 database_events
+
+Gets or sets the events that triggers the trigger.
+
+  my $ok = $trigger->database_events('insert');
 
 =cut
 
-    my $self = shift;
+	my $self = shift;
+	
+	if ( my $arg = shift ) {
+		if (ref $arg eq "ARRAY"){
+			map  {
+				$_ = lc; 
+				$_ =~ s/\s+/ /g;  
+				return $self->error("Invalid event '$_' in database_events") unless ( $_ =~ /^(insert|update|update_on|delete)$/ );
+			} @$arg ;
+			@{ $self->{'database_events'} } = @$arg;
+			
+		}else{
+			return $self->error("Invalid argument to database_events");
+		};
+		
+	}
 
-    if ( my $arg = shift ) {
-        $arg =  lc $arg;
-        $arg =~ s/\s+/ /g;
-        if ( $arg =~ /^(insert|update|update_on|delete)$/ ) {
-            $self->{'database_event'} = $arg;
-        }
-        else {
-            return 
-                $self->error("Invalid argument '$arg' to database_event");
-        }
-    }
-
-    return $self->{'database_event'};
+	return $self->{'database_events'};
 }
 
 # ----------------------------------------------------------------------
@@ -331,6 +359,30 @@ Get or set the trigger's schema object.
     return $self->{'schema'};
 }
 
+# ----------------------------------------------------------------------
+sub compare_arrays {
+
+=pod
+
+=head2 compare_arrays
+
+Compare two arrays.
+
+=cut
+	
+	my ($first, $second) = @_;
+	no warnings;  # silence spurious -w undef complaints
+
+	return 0 unless (ref $first eq 'ARRAY' and ref $second eq 'ARRAY' ) ;
+	return 0 unless @$first == @$second;
+	my @first = sort @$first;
+	my @second = sort @$second;
+	for (my $i = 0; $i < scalar @first; $i++) {
+		return 0 if @first[$i] ne @second[$i];
+		}
+	return 1;
+}
+
 # ----------------------------------------------------------------------
 sub equals {
 
@@ -352,7 +404,7 @@ Determines if this trigger is the same as another
     return 0 unless $case_insensitive ? uc($self->name) eq uc($other->name) : $self->name eq $other->name;
     #return 0 unless $self->is_valid eq $other->is_valid;
     return 0 unless $self->perform_action_when eq $other->perform_action_when;
-    return 0 unless $self->database_event eq $other->database_event;
+    return 0 unless compare_arrays($self->database_events,$other->database_events) ;
     return 0 unless $self->on_table eq $other->on_table;
     return 0 unless $self->action eq $other->action;
     return 0 unless $self->_compare_objects(scalar $self->extra, scalar $other->extra);
